@@ -859,7 +859,7 @@ command_watch (GIOChannel   *source,
                         if (strstr (line, "WINDOW ID=")) {
                                 guint32 id;
                                 char    c;
-                                if (1 == sscanf (line, " WINDOW ID= 0x%x %c", &id, &c)) {
+                                if (1 == sscanf (line, " WINDOW ID= %" G_GUINT32_FORMAT " %c", &id, &c)) {
                                         create_socket (window, id);
                                 }
                         } else if (strstr (line, "NOTICE=")) {
@@ -889,8 +889,9 @@ command_watch (GIOChannel   *source,
                         break;
                 }
 
-        } else if (condition & G_IO_HUP)
+        } else if (condition & G_IO_HUP) {
                 finished = TRUE;
+        }
 
         if (finished) {
                 gs_window_dialog_finish (window);
@@ -1191,9 +1192,10 @@ static void
 queue_key_event (GSWindow    *window,
                  GdkEventKey *event)
 {
-        /* Eat the first return or space */
+        /* Eat the first return, enter, or space */
         if (window->priv->key_events == NULL
             && (event->keyval == GDK_Return
+                || event->keyval == GDK_KP_Enter
                 || event->keyval == GDK_space)) {
                 return;
         }
@@ -1311,6 +1313,24 @@ gs_window_real_size_request (GtkWidget      *widget,
         gs_window_move_resize_window (window, position_changed, size_changed);
 }
 
+static gboolean
+gs_window_real_grab_broken (GtkWidget          *widget,
+                            GdkEventGrabBroken *event)
+{
+        if (event->grab_window != NULL) {
+                gs_debug ("Grab broken on window %X %s, new grab on window %X",
+                          (guint32) GDK_WINDOW_XID (event->window),
+                          event->keyboard ? "keyboard" : "pointer",
+                          (guint32) GDK_WINDOW_XID (event->grab_window));
+        } else {
+                gs_debug ("Grab broken on window %X %s, new grab is outside application",
+                          (guint32) GDK_WINDOW_XID (event->window),
+                          event->keyboard ? "keyboard" : "pointer");
+        }
+
+        return FALSE;
+}
+
 static void
 gs_window_class_init (GSWindowClass *klass)
 {
@@ -1330,6 +1350,7 @@ gs_window_class_init (GSWindowClass *klass)
         widget_class->key_press_event     = gs_window_real_key_press_event;
         widget_class->motion_notify_event = gs_window_real_motion_notify_event;
         widget_class->size_request        = gs_window_real_size_request;
+        widget_class->grab_broken_event   = gs_window_real_grab_broken;
 
         g_type_class_add_private (klass, sizeof (GSWindowPrivate));
 
@@ -1399,7 +1420,7 @@ gs_window_class_init (GSWindowClass *klass)
                                          PROP_MONITOR,
                                          g_param_spec_int ("monitor",
                                                            "Xinerama monitor",
-                                                           "The monitor (in terms of Xinerama) which the panel is on",
+                                                           "The monitor (in terms of Xinerama) which the window is on",
                                                            0,
                                                            G_MAXINT,
                                                            0,
